.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2015 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

API doc
~~~~~~~

**exceptions**

.. automodule:: anyblok.bloks.io.exceptions

.. autoexception:: IOException
    :members:
    :show-inheritance:
    :noindex:

.. autoexception:: IOMappingCheckException
    :members:
    :show-inheritance:
    :noindex:

.. autoexception:: IOMappingSetException
    :members:
    :show-inheritance:
    :noindex:

.. autoexception:: ImporterException
    :members:
    :show-inheritance:
    :noindex:

.. autoexception:: ExporterException
    :members:
    :show-inheritance:
    :noindex:

.. autoexception:: FormaterException
    :members:
    :show-inheritance:
    :noindex:

**core**

.. automodule:: anyblok.bloks.io.core

.. autoanyblok-declaration:: Query
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: SqlBase
    :members:
    :show-inheritance:
    :noindex:

**mapping**

.. automodule:: anyblok.bloks.io.mapping

.. autoanyblok-declaration:: Mapping
    :members:
    :show-inheritance:
    :noindex:

**mixin**

.. automodule:: anyblok.bloks.io.mixin

.. autoanyblok-declaration:: IOMixin
    :members:
    :show-inheritance:
    :noindex:

**importer**

.. automodule:: anyblok.bloks.io.importer

.. autoanyblok-declaration:: Importer
    :members:
    :show-inheritance:
    :noindex:

**exporter**

.. automodule:: anyblok.bloks.io.exporter

.. autoanyblok-declaration:: Exporter
    :members:
    :show-inheritance:
    :noindex:

**formater**

.. automodule:: anyblok.bloks.io.formater

.. autoanyblok-declaration:: Formater
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Float
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Decimal
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Json
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Interval
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Integer
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: SmallInteger
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: BigInteger
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Boolean
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Time
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Date
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: DateTime
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Many2One
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: One2One
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: Many2Many
    :members:
    :show-inheritance:
    :noindex:

.. autoanyblok-declaration:: One2Many
    :members:
    :show-inheritance:
    :noindex:
